<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Print</name>
    <message>
        <source>&amp;Print</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wy&amp;drukuj...
Wy&amp;drukuj</translatorcomment>
        <translation type="obsolete">Wy&amp;drukuj</translation>
    </message>
    <message>
        <source>Print current drawing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Drukuj bieżący rysunek</translation>
    </message>
</context>
<context>
    <name>PrintCurrentView</name>
    <message>
        <location filename="../PrintCurrentViewInit.js" line="+2"/>
        <source>Print &amp;Current View</source>
        <translation>Drukuj &amp;aktualny widok</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Print current view</source>
        <translation>Drukuje aktualny widok</translation>
    </message>
</context>
</TS>
